package knotts;

import org.eclipse.persistence.sessions.Project;
import org.eclipse.persistence.oxm.NamespaceResolver;
import org.eclipse.persistence.oxm.XMLDescriptor;
import org.eclipse.persistence.oxm.mappings.XMLTransformationMapping;
import org.eclipse.persistence.mappings.transformers.AttributeTransformer;
import org.eclipse.persistence.mappings.transformers.FieldTransformer;

public class MyProject extends Project {

	public MyProject() {
		super();
		this.addDescriptor(getCustomerDescriptor());
	}
	
	XMLDescriptor getCustomerDescriptor() {
		org.eclipse.persistence.oxm.XMLDescriptor xmlDescriptor = new XMLDescriptor();
		xmlDescriptor.setJavaClass(Customer.class);
		xmlDescriptor.setDefaultRootElement("ns:customer");
		
		NamespaceResolver namespaceResolver = new NamespaceResolver();
		namespaceResolver.put("ns", "http://www.example.com");
		xmlDescriptor.setNamespaceResolver(namespaceResolver);
		
		/*
		 * When mapping logic above and beyond our built-in mappings is required you can normally fall back
		 * on a Transformation Mapping.  Here we will use one to encapsulate the logic from your use case.
		 */
		XMLTransformationMapping addressMapping = new XMLTransformationMapping();
		addressMapping.setAttributeName("address01");
		
		/*
		 * AttributeTransformers are used to build to build the property value for the domain object.
		 */
		AttributeTransformer address01AttributeTransformer = new Address01AttributeTransformer();
		addressMapping.setAttributeTransformer(address01AttributeTransformer);
		
		/*
		 * FieldTransformers are used to build the XML document.
		 */
		FieldTransformer xmlAddressLine01FieldTransformer = new XmlAddressLine01FieldTransformer();
		addressMapping.addFieldTransformer("ns:AddressLine01/text()", xmlAddressLine01FieldTransformer);
		
		/*
		 * A FieldTransformer is required for every field you want available in the Record passed to the
		 * AttributeTransformer.  In this example the EmptyFieldTransformer does not do anything except
		 * meet the above requirement.
		 */
		FieldTransformer emptyFieldTransformer = new EmptyFieldTransformer();
		addressMapping.addFieldTransformer("ns:HouseNbr/text()", emptyFieldTransformer);
		addressMapping.addFieldTransformer("ns:StreetName/text()", emptyFieldTransformer);
		xmlDescriptor.addMapping(addressMapping);

		return xmlDescriptor;
	}
	
}
